@@ -1,11 +1,11 @@
-from typing import TYPE_CHECKING, Callable, Optional, Tuple
+from typing import TYPE_CHECKING, Optional, Tuple
 
 from .exceptions import get_status_code_error
 from .specs.openapi.checks import content_type_conformance, response_schema_conformance, status_code_conformance
 from .utils import GenericResponse
 
 if TYPE_CHECKING:
-    from .models import Case
+    from .models import Case, CheckFunction
 
 
 def not_a_server_error(response: GenericResponse, case: "Case") -> Optional[bool]:  # pylint: disable=useless-return
@@ -18,4 +18,4 @@ def not_a_server_error(response: GenericResponse, case: "Case") -> Optional[bool
 
 DEFAULT_CHECKS = (not_a_server_error,)
 OPTIONAL_CHECKS = (status_code_conformance, content_type_conformance, response_schema_conformance)
-ALL_CHECKS: Tuple[Callable[[GenericResponse, "Case"], Optional[bool]], ...] = DEFAULT_CHECKS + OPTIONAL_CHECKS
+ALL_CHECKS: Tuple["CheckFunction", ...] = DEFAULT_CHECKS + OPTIONAL_CHECKS
