@@ -6,17 +6,19 @@ from typing import Callable, Dict, Generator, Iterable, List, Optional, Tuple, U
 
 import click
 import hypothesis
-import requests
 import yaml
 
 from .. import checks as checks_module
-from .. import models, runner
+from .. import runner
+from .. import targets as targets_module
+from ..constants import DEFAULT_STATEFUL_RECURSION_LIMIT
 from ..fixups import ALL_FIXUPS
 from ..hooks import GLOBAL_HOOK_DISPATCHER, HookContext, HookDispatcher, HookScope
-from ..runner import DEFAULT_STATEFUL_RECURSION_LIMIT, events
-from ..runner.targeted import DEFAULT_TARGETS_NAMES, Target
+from ..models import CheckFunction
+from ..runner import events
+from ..stateful import Stateful
+from ..targets import Target
 from ..types import Filter
-from ..utils import WSGIResponse
 from . import callbacks, cassettes, output
 from .context import ExecutionContext
 from .handlers import EventHandler
@@ -30,26 +32,50 @@ except ImportError:
     from yaml import SafeLoader  # type: ignore
 
 
+def _get_callable_names(items: Tuple[Callable, ...]) -> Tuple[str, ...]:
+    return tuple(item.__name__ for item in items)
+
+
 CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help"]}
 
-DEFAULT_CHECKS_NAMES = tuple(check.__name__ for check in checks_module.DEFAULT_CHECKS)
-ALL_CHECKS_NAMES = tuple(check.__name__ for check in checks_module.ALL_CHECKS)
+DEFAULT_CHECKS_NAMES = _get_callable_names(checks_module.DEFAULT_CHECKS)
+ALL_CHECKS_NAMES = _get_callable_names(checks_module.ALL_CHECKS)
 CHECKS_TYPE = click.Choice((*ALL_CHECKS_NAMES, "all"))
+
+DEFAULT_TARGETS_NAMES = _get_callable_names(targets_module.DEFAULT_TARGETS)
+ALL_TARGETS_NAMES = _get_callable_names(targets_module.ALL_TARGETS)
+TARGETS_TYPE = click.Choice((*ALL_TARGETS_NAMES, "all"))
+
 DEFAULT_WORKERS = 1
 MAX_WORKERS = 64
 
 
-def register_check(function: Callable[[Union[requests.Response, WSGIResponse], models.Case], None]) -> None:
+def register_target(function: Target) -> Target:
+    """Register a new testing target for schemathesis CLI."""
+    targets_module.ALL_TARGETS += (function,)
+    TARGETS_TYPE.choices += (function.__name__,)  # type: ignore
+    return function
+
+
+def register_check(function: CheckFunction) -> CheckFunction:
     """Register a new check for schemathesis CLI."""
     checks_module.ALL_CHECKS += (function,)
     CHECKS_TYPE.choices += (function.__name__,)  # type: ignore
+    return function
 
 
 def reset_checks() -> None:
     """Get checks list to their default state."""
     # Useful in tests
     checks_module.ALL_CHECKS = checks_module.DEFAULT_CHECKS + checks_module.OPTIONAL_CHECKS
-    CHECKS_TYPE.choices = tuple(check.__name__ for check in checks_module.ALL_CHECKS) + ("all",)
+    CHECKS_TYPE.choices = _get_callable_names(checks_module.ALL_CHECKS) + ("all",)
+
+
+def reset_targets() -> None:
+    """Get targets list to their default state."""
+    # Useful in tests
+    targets_module.ALL_TARGETS = targets_module.DEFAULT_TARGETS + targets_module.OPTIONAL_TARGETS
+    TARGETS_TYPE.choices = _get_callable_names(targets_module.ALL_TARGETS) + ("all",)
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
@@ -72,7 +98,7 @@ def schemathesis(pre_run: Optional[str] = None) -> None:
     "targets",
     multiple=True,
     help="Targets for input generation.",
-    type=click.Choice([target.name for target in Target]),
+    type=TARGETS_TYPE,
     default=DEFAULT_TARGETS_NAMES,
 )
 @click.option(
@@ -155,7 +181,9 @@ def schemathesis(pre_run: Optional[str] = None) -> None:
     type=click.IntRange(1),
 )
 @click.option("--validate-schema", help="Enable or disable validation of input schema.", type=bool, default=True)
-@click.option("--junit-xml", help="Create junit-xml style report file at given path.", type=click.File("w"))
+@click.option(
+    "--junit-xml", help="Create junit-xml style report file at given path.", type=click.File("w", encoding="utf-8")
+)
 @click.option(
     "--show-errors-tracebacks",
     help="Show full tracebacks for internal errors.",
@@ -163,14 +191,21 @@ def schemathesis(pre_run: Optional[str] = None) -> None:
     is_eager=True,
     default=False,
 )
-@click.option("--store-network-log", help="Store requests and responses into a file.", type=click.File("w"))
+@click.option(
+    "--store-network-log", help="Store requests and responses into a file.", type=click.File("w", encoding="utf-8")
+)
 @click.option(
     "--fixups",
     help="Install specified compatibility fixups.",
     multiple=True,
     type=click.Choice(list(ALL_FIXUPS) + ["all"]),
 )
-@click.option("--stateful", help="Utilize stateful testing capabilities.", type=click.Choice(["links"]))
+@click.option(
+    "--stateful",
+    help="Utilize stateful testing capabilities.",
+    type=click.Choice([item.name for item in Stateful]),
+    callback=callbacks.convert_stateful,
+)
 @click.option(
     "--stateful-recursion-limit",
     help="Limit recursion depth for stateful testing.",
@@ -180,7 +215,7 @@ def schemathesis(pre_run: Optional[str] = None) -> None:
 @click.option(
     "--hypothesis-deadline",
     help="Duration in milliseconds that each individual example with a test is not allowed to exceed.",
-    # max value to avoid overflow. It is maximum amount of days in milliseconds
+    # max value to avoid overflow. It is the maximum amount of days in milliseconds
     type=OptionalInt(1, 999999999 * 24 * 3600 * 1000),
 )
 @click.option("--hypothesis-derandomize", help="Use Hypothesis's deterministic mode.", is_flag=True, default=None)
@@ -227,7 +262,7 @@ def run(  # pylint: disable=too-many-arguments
     show_errors_tracebacks: bool = False,
     store_network_log: Optional[click.utils.LazyFile] = None,
     fixups: Tuple[str] = (),  # type: ignore
-    stateful: Optional[str] = None,
+    stateful: Optional[Stateful] = None,
     stateful_recursion_limit: int = DEFAULT_STATEFUL_RECURSION_LIMIT,
     hypothesis_deadline: Optional[Union[int, NotSet]] = None,
     hypothesis_derandomize: Optional[bool] = None,
@@ -244,7 +279,7 @@ def run(  # pylint: disable=too-many-arguments
     SCHEMA must be a valid URL or file path pointing to an Open API / Swagger specification.
     """
     # pylint: disable=too-many-locals
-    selected_targets = tuple(target for target in Target if target.name in targets)
+    selected_targets = tuple(target for target in targets_module.ALL_TARGETS if target.__name__ in targets)
 
     if "all" in checks:
         selected_checks = checks_module.ALL_CHECKS
@@ -297,11 +332,11 @@ def load_hook(module_name: str) -> None:
     try:
         sys.path.append(os.getcwd())  # fix ModuleNotFoundError module in cwd
         __import__(module_name)
-    except Exception:
+    except Exception as exc:
         click.secho("An exception happened during the hook loading:\n", fg="red")
         message = traceback.format_exc()
         click.secho(message, fg="red")
-        raise click.Abort()
+        raise click.Abort() from exc
 
 
 class OutputStyle(Enum):
