@@ -8,6 +8,7 @@ import hypothesis
 from requests import PreparedRequest, RequestException
 
 from .. import utils
+from ..stateful import Stateful
 
 
 def validate_schema(ctx: click.core.Context, param: click.core.Parameter, raw_value: str) -> str:
@@ -25,8 +26,8 @@ def validate_schema(ctx: click.core.Context, param: click.core.Parameter, raw_va
 def _validate_url(value: str) -> None:
     try:
         PreparedRequest().prepare_url(value, {})  # type: ignore
-    except RequestException:
-        raise click.UsageError("Invalid SCHEMA, must be a valid URL or file path.")
+    except RequestException as exc:
+        raise click.UsageError("Invalid SCHEMA, must be a valid URL or file path.") from exc
 
 
 def validate_base_url(ctx: click.core.Context, param: click.core.Parameter, raw_value: str) -> str:
@@ -41,7 +42,7 @@ def validate_app(ctx: click.core.Context, param: click.core.Parameter, raw_value
     try:
         utils.import_app(raw_value)
         # String is returned instead of an app because it might be passed to a subprocess
-        # Since most of app instances are not-transferable to another process, they are passed as strings and
+        # Since most app instances are not-transferable to another process, they are passed as strings and
         # imported in a subprocess
         return raw_value
     except Exception as exc:
@@ -110,9 +111,15 @@ def convert_verbosity(
     return hypothesis.Verbosity[value]
 
 
+def convert_stateful(ctx: click.core.Context, param: click.core.Parameter, value: Optional[str]) -> Optional[Stateful]:
+    if value is None:
+        return value
+    return Stateful[value]
+
+
 @contextmanager
 def reraise_format_error(raw_value: str) -> Generator[None, None, None]:
     try:
         yield
-    except ValueError:
-        raise click.BadParameter(f"Should be in KEY:VALUE format. Got: {raw_value}")
+    except ValueError as exc:
+        raise click.BadParameter(f"Should be in KEY:VALUE format. Got: {raw_value}") from exc
