@@ -2,10 +2,9 @@ from hashlib import sha1
 from typing import Dict, Type, Union
 
 import attr
-import requests
 from jsonschema import ValidationError
 
-from .utils import WSGIResponse
+from .utils import GenericResponse
 
 
 class CheckFailed(AssertionError):
@@ -16,7 +15,7 @@ CACHE: Dict[Union[str, int], Type[CheckFailed]] = {}
 
 
 def get_exception(name: str) -> Type[CheckFailed]:
-    """Create a new exception class with provided name or fetch one from cache."""
+    """Create a new exception class with provided name or fetch one from the cache."""
     if name in CACHE:
         exception_class = CACHE[name]
     else:
@@ -61,5 +60,5 @@ class InvalidSchema(Exception):
 
 @attr.s  # pragma: no mutate
 class HTTPError(Exception):
-    response: Union[requests.Response, WSGIResponse] = attr.ib()  # pragma: no mutate
+    response: GenericResponse = attr.ib()  # pragma: no mutate
     url: str = attr.ib()  # pragma: no mutate
