@@ -1,15 +1,17 @@
 import inspect
 from collections import defaultdict
 from enum import Enum, unique
-from typing import Any, Callable, DefaultDict, Dict, List, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, DefaultDict, Dict, List, Optional, Union, cast
 
 import attr
 from hypothesis import strategies as st
 
-from .models import Case, Endpoint
 from .types import GenericTest
 from .utils import GenericResponse
 
+if TYPE_CHECKING:
+    from .models import Case, Endpoint
+
 
 class HookLocation(Enum):
     path_parameters = 1
@@ -27,17 +29,17 @@ class HookScope(Enum):
     TEST = 3
 
 
-@attr.s(slots=True)
+@attr.s(slots=True)  # pragma: no mutate
 class RegisteredHook:
-    signature: inspect.Signature = attr.ib()
-    scopes: List[HookScope] = attr.ib()
+    signature: inspect.Signature = attr.ib()  # pragma: no mutate
+    scopes: List[HookScope] = attr.ib()  # pragma: no mutate
 
 
 @attr.s(slots=True)  # pragma: no mutate
 class HookContext:
     """A context that is passed to some hook functions."""
 
-    endpoint: Optional[Endpoint] = attr.ib(default=None)  # pragma: no mutate
+    endpoint: Optional["Endpoint"] = attr.ib(default=None)  # pragma: no mutate
 
 
 @attr.s(slots=True)  # pragma: no mutate
@@ -47,7 +49,7 @@ class HookDispatcher:
     Provides a mechanism to extend Schemathesis in registered hook points.
     """
 
-    scope: HookScope = attr.ib()
+    scope: HookScope = attr.ib()  # pragma: no mutate
     _hooks: DefaultDict[str, List[Callable]] = attr.ib(factory=lambda: defaultdict(list))  # pragma: no mutate
     _specs: Dict[str, RegisteredHook] = {}  # pragma: no mutate
 
@@ -133,11 +135,11 @@ class HookDispatcher:
         spec = self._specs.get(name)
         if spec is None:
             raise TypeError(f"There is no hook with name '{name}'")
-        # Some hooks are not present on all levels. We need to avoid registering hooks on wrong levels
+        # Some hooks are not present on all levels. We need to avoid registering hooks on wrong levels.
         if self.scope not in spec.scopes:
             scopes = ", ".join(scope.name for scope in spec.scopes)
             raise ValueError(
-                f"Can not register hook '{name}' on {self.scope.name} scope dispatcher. "
+                f"Cannot register hook '{name}' on {self.scope.name} scope dispatcher. "
                 f"Use a dispatcher with {scopes} scope(s) instead"
             )
         signature = inspect.signature(hook)
@@ -147,7 +149,7 @@ class HookDispatcher:
             )
 
     def get_all_by_name(self, name: str) -> List[Callable]:
-        """Get a list of hooks registered for name."""
+        """Get a list of hooks registered for a name."""
         return self._hooks.get(name, [])
 
     def dispatch(self, name: str, context: HookContext, *args: Any, **kwargs: Any) -> None:
@@ -213,7 +215,7 @@ def before_load_schema(context: HookContext, raw_schema: Dict[str, Any]) -> None
 
 
 @all_scopes
-def before_add_examples(context: HookContext, examples: List[Case]) -> None:
+def before_add_examples(context: HookContext, examples: List["Case"]) -> None:
     """Called before explicit examples are added to a test via `@example` decorator.
 
     `examples` is a list that could be extended with examples provided by the user.
@@ -221,7 +223,7 @@ def before_add_examples(context: HookContext, examples: List[Case]) -> None:
 
 
 @HookDispatcher.register_spec([HookScope.GLOBAL])
-def add_case(context: HookContext, case: Case, response: GenericResponse) -> Optional[Case]:
+def add_case(context: HookContext, case: "Case", response: GenericResponse) -> Optional["Case"]:
     """Creates an additional test per endpoint. If this hook returns None, no additional test created.
 
     Called with a copy of the original case object and the server's response to the original case.
