@@ -64,8 +64,8 @@ def from_uri(
     response = requests.get(uri, **kwargs)
     try:
         response.raise_for_status()
-    except requests.HTTPError:
-        raise HTTPError(response=response, url=uri)
+    except requests.HTTPError as exc:
+        raise HTTPError(response=response, url=uri) from exc
     return from_file(
         response.text,
         location=uri,
@@ -90,7 +90,7 @@ def from_file(
     *,
     app: Any = None,
     validate_schema: bool = True,
-    **kwargs: Any,  # needed in runner to have compatible API across all loaders
+    **kwargs: Any,  # needed in the runner to have compatible API across all loaders
 ) -> BaseOpenAPISchema:
     """Load a file content and parse to schema instance.
 
