@@ -16,7 +16,6 @@ import werkzeug
 from hypothesis.strategies import SearchStrategy
 from starlette.testclient import TestClient as ASGIClient
 
-from .checks import ALL_CHECKS
 from .exceptions import InvalidSchema
 from .types import Body, Cookies, FormData, Headers, PathParameters, Query
 from .utils import GenericResponse, WSGIResponse
@@ -24,14 +23,20 @@ from .utils import GenericResponse, WSGIResponse
 if TYPE_CHECKING:
     from .hooks import HookDispatcher
     from .schemas import BaseSchema
-    from .stateful import StatefulTest
+    from .stateful import Feedback, Stateful, StatefulTest
+
+
+MISSING_STATEFUL_ARGUMENT_MESSAGE = (
+    "To use `store_response` you need to enable stateful testing by adding "
+    "`stateful=Stateful.links` to your `parametrize` call."
+)
 
 
 @attr.s(slots=True)  # pragma: no mutate
 class Case:
     """A single test case parameters."""
 
-    endpoint: "Endpoint" = attr.ib()  # pragma: no mutate
+    endpoint: "Endpoint" = attr.ib(repr=False)  # pragma: no mutate
     path_parameters: Optional[PathParameters] = attr.ib(default=None)  # pragma: no mutate
     headers: Optional[Headers] = attr.ib(default=None)  # pragma: no mutate
     cookies: Optional[Cookies] = attr.ib(default=None)  # pragma: no mutate
@@ -39,6 +44,8 @@ class Case:
     body: Optional[Body] = attr.ib(default=None)  # pragma: no mutate
     form_data: Optional[FormData] = attr.ib(default=None)  # pragma: no mutate
 
+    feedback: "Feedback" = attr.ib(repr=False, default=None)
+
     @property
     def path(self) -> str:
         return self.endpoint.path
@@ -67,7 +74,7 @@ class Case:
         except KeyError as variable:
             raise InvalidSchema(
                 f"Missing path parameter {variable}. It either not defined or has no `required: true` in its definition"
-            )
+            ) from variable
 
     def get_full_base_url(self) -> Optional[str]:
         """Create a full base url, adding "localhost" for WSGI apps."""
@@ -77,6 +84,27 @@ class Case:
             return urlunsplit(("http", "localhost", path or "", "", ""))
         return self.base_url
 
+    def as_text_lines(self) -> List[str]:
+        """Textual representation.
+
+        Each component is a separate line.
+        """
+        output = {
+            "Path parameters": self.path_parameters,
+            "Headers": self.headers,
+            "Cookies": self.cookies,
+            "Query": self.query,
+            "Body": self.body,
+            "Form data": self.form_data,
+        }
+        max_length = max(map(len, output))
+        template = f"{{:<{max_length}}} : {{}}"
+        return [
+            template.format(key, value)
+            for key, value in output.items()
+            if (key == "Body" and value is not None) or value not in (None, {})
+        ]
+
     def get_code_to_reproduce(self, headers: Optional[Dict[str, Any]] = None) -> str:
         """Construct a Python code to reproduce this case with `requests`."""
         base_url = self.get_full_base_url()
@@ -156,8 +184,15 @@ class Case:
         response = session.request(**data)  # type: ignore
         if close_session:
             session.close()
+        if self.feedback:
+            self.store_response(response)
         return response
 
+    def store_response(self, response: GenericResponse) -> None:
+        if self.feedback is None:
+            raise RuntimeError(MISSING_STATEFUL_ARGUMENT_MESSAGE)
+        self.feedback.add_test_case(self, response)
+
     def as_werkzeug_kwargs(self, headers: Optional[Dict[str, str]] = None) -> Dict[str, Any]:
         """Convert the case into a dictionary acceptable by werkzeug.Client."""
         final_headers = self.headers.copy() if self.headers is not None else {}
@@ -191,7 +226,10 @@ class Case:
         data = self.as_werkzeug_kwargs(headers)
         client = werkzeug.Client(application, WSGIResponse)
         with cookie_handler(client, self.cookies):
-            return client.open(**data, **kwargs)
+            response = client.open(**data, **kwargs)
+        if self.feedback:
+            self.store_response(response)
+        return response
 
     def call_asgi(
         self,
@@ -212,9 +250,12 @@ class Case:
 
     def validate_response(
         self,
-        response: Union[requests.Response, WSGIResponse],
-        checks: Tuple[Callable[[Union[requests.Response, WSGIResponse], "Case"], Optional[bool]], ...] = ALL_CHECKS,
+        response: GenericResponse,
+        checks: Tuple["CheckFunction", ...] = (),
     ) -> None:
+        from .checks import ALL_CHECKS  # pylint: disable=import-outside-toplevel
+
+        checks = checks or ALL_CHECKS
         errors = []
         for check in checks:
             try:
@@ -309,34 +350,31 @@ class Endpoint:
     schema: "BaseSchema" = attr.ib()  # pragma: no mutate
     app: Any = attr.ib(default=None)  # pragma: no mutate
     base_url: Optional[str] = attr.ib(default=None)  # pragma: no mutate
-    path_parameters: Optional[PathParameters] = attr.ib(default=None)  # pragma: no mutate
-    headers: Optional[Headers] = attr.ib(default=None)  # pragma: no mutate
-    cookies: Optional[Cookies] = attr.ib(default=None)  # pragma: no mutate
-    query: Optional[Query] = attr.ib(default=None)  # pragma: no mutate
-    body: Optional[Body] = attr.ib(default=None)  # pragma: no mutate
-    form_data: Optional[FormData] = attr.ib(default=None)  # pragma: no mutate
+    path_parameters: Optional[Dict[str, Any]] = attr.ib(default=None)  # pragma: no mutate
+    headers: Optional[Dict[str, Any]] = attr.ib(default=None)  # pragma: no mutate
+    cookies: Optional[Dict[str, Any]] = attr.ib(default=None)  # pragma: no mutate
+    query: Optional[Dict[str, Any]] = attr.ib(default=None)  # pragma: no mutate
+    body: Optional[Dict[str, Any]] = attr.ib(default=None)  # pragma: no mutate
+    form_data: Optional[Dict[str, Any]] = attr.ib(default=None)  # pragma: no mutate
 
     @property
     def full_path(self) -> str:
         return self.schema.get_full_path(self.path)
 
-    def as_strategy(self, hooks: Optional["HookDispatcher"] = None) -> SearchStrategy:
-        from ._hypothesis import get_case_strategy  # pylint: disable=import-outside-toplevel
-
-        return get_case_strategy(self, hooks)
+    def as_strategy(
+        self, hooks: Optional["HookDispatcher"] = None, feedback: Optional["Feedback"] = None
+    ) -> SearchStrategy:
+        return self.schema.get_case_strategy(self, hooks, feedback)
 
     def get_strategies_from_examples(self) -> List[SearchStrategy[Case]]:
-        """Get examples from endpoint."""
+        """Get examples from the endpoint."""
         return self.schema.get_strategies_from_examples(self)
 
-    def get_stateful_tests(self, response: GenericResponse, stateful: Optional[str]) -> Sequence["StatefulTest"]:
+    def get_stateful_tests(self, response: GenericResponse, stateful: Optional["Stateful"]) -> Sequence["StatefulTest"]:
         return self.schema.get_stateful_tests(response, self, stateful)
 
     def get_hypothesis_conversions(self, location: str) -> Optional[Callable]:
-        definitions = [item for item in self.definition.resolved.get("parameters", []) if item["in"] == location]
-        if definitions:
-            return self.schema.get_hypothesis_conversion(definitions)
-        return None
+        return self.schema.get_hypothesis_conversion(self, location)
 
     def prepare_multipart(self, form_data: Optional[FormData]) -> Tuple[Optional[List], Optional[Dict[str, Any]]]:
         if not form_data:
@@ -362,6 +400,23 @@ class Endpoint:
             form_data=deepcopy(self.form_data),
         )
 
+    def clone(self, **components: Any) -> "Endpoint":
+        """Create a new instance of this endpoint with updated components."""
+        return self.__class__(
+            path=self.path,
+            method=self.method,
+            definition=self.definition,
+            schema=self.schema,
+            app=self.app,
+            base_url=self.base_url,
+            path_parameters=components["path_parameters"],
+            query=components["query"],
+            headers=components["headers"],
+            cookies=components["cookies"],
+            body=components["body"],
+            form_data=self.form_data,
+        )
+
 
 class Status(IntEnum):
     """Status of an action or multiple actions."""
@@ -577,7 +632,7 @@ class TestResultSet:
 
     @property
     def total(self) -> Dict[str, Dict[Union[str, Status], int]]:
-        """Aggregated statistic about test results."""
+        """An aggregated statistic about test results."""
         output: Dict[str, Dict[Union[str, Status], int]] = {}
         for item in self.results:
             for check in item.checks:
