@@ -7,13 +7,15 @@ from starlette.applications import Starlette
 from .. import fixups as _fixups
 from .. import loaders
 from ..checks import DEFAULT_CHECKS
+from ..constants import DEFAULT_STATEFUL_RECURSION_LIMIT
 from ..models import CheckFunction
 from ..schemas import BaseSchema
+from ..stateful import Stateful
+from ..targets import DEFAULT_TARGETS, Target
 from ..types import Filter, NotSet, RawAuth
 from ..utils import dict_not_none_values, dict_true_values, file_exists, get_requests_auth, import_app
 from . import events
 from .impl import (
-    DEFAULT_STATEFUL_RECURSION_LIMIT,
     BaseRunner,
     SingleThreadASGIRunner,
     SingleThreadRunner,
@@ -22,7 +24,6 @@ from .impl import (
     ThreadPoolRunner,
     ThreadPoolWSGIRunner,
 )
-from .targeted import DEFAULT_TARGETS, Target
 
 
 def prepare(  # pylint: disable=too-many-arguments
@@ -36,7 +37,7 @@ def prepare(  # pylint: disable=too-many-arguments
     exit_first: bool = False,
     store_interactions: bool = False,
     fixups: Iterable[str] = (),
-    stateful: Optional[str] = None,
+    stateful: Optional[Stateful] = None,
     stateful_recursion_limit: int = DEFAULT_STATEFUL_RECURSION_LIMIT,
     # Schema loading
     loader: Callable = loaders.from_uri,
@@ -146,7 +147,7 @@ def execute_from_schema(
     exit_first: bool = False,
     store_interactions: bool = False,
     fixups: Iterable[str] = (),
-    stateful: Optional[str] = None,
+    stateful: Optional[Stateful] = None,
     stateful_recursion_limit: int = DEFAULT_STATEFUL_RECURSION_LIMIT,
 ) -> Generator[events.ExecutionEvent, None, None]:
     """Execute tests for the given schema.
@@ -309,7 +310,7 @@ def load_schema(
         if file_exists(schema_uri):
             loader = loaders.from_path
         elif app is not None and not urlparse(schema_uri).netloc:
-            # If `schema` is not an existing filesystem path or an URL then it is considered as an endpoint with
+            # If `schema` is not an existing filesystem path, or a URL then it is considered as an endpoint with
             # the given app
             loader = loaders.get_loader_for_app(app)
             loader_options.update(dict_true_values(headers=headers))
@@ -339,7 +340,7 @@ def prepare_hypothesis_options(  # pylint: disable=too-many-arguments
         suppress_health_check=suppress_health_check,
         verbosity=verbosity,
     )
-    # `deadline` is special, since Hypothesis allows to pass `None`
+    # `deadline` is special, since Hypothesis allows passing `None`
     if deadline is not None:
         if isinstance(deadline, NotSet):
             options["deadline"] = None
