@@ -9,11 +9,12 @@ import hypothesis
 
 from ..._hypothesis import make_test_or_exception
 from ...models import CheckFunction, TestResultSet
+from ...stateful import Feedback, Stateful
+from ...targets import Target
 from ...types import RawAuth
 from ...utils import capture_hypothesis_output, get_requests_auth
 from .. import events
-from ..targeted import Target
-from .core import BaseRunner, Feedback, asgi_test, get_session, network_test, run_test, wsgi_test
+from .core import BaseRunner, asgi_test, get_session, network_test, run_test, wsgi_test
 
 
 def _run_task(
@@ -25,7 +26,7 @@ def _run_task(
     settings: hypothesis.settings,
     seed: Optional[int],
     results: TestResultSet,
-    stateful: Optional[str],
+    stateful: Optional[Stateful],
     stateful_recursion_limit: int,
     **kwargs: Any,
 ) -> None:
@@ -61,7 +62,7 @@ def thread_task(
     headers: Optional[Dict[str, Any]],
     seed: Optional[int],
     results: TestResultSet,
-    stateful: Optional[str],
+    stateful: Optional[Stateful],
     stateful_recursion_limit: int,
     kwargs: Any,
 ) -> None:
@@ -97,7 +98,7 @@ def wsgi_thread_task(
     settings: hypothesis.settings,
     seed: Optional[int],
     results: TestResultSet,
-    stateful: Optional[str],
+    stateful: Optional[Stateful],
     stateful_recursion_limit: int,
     kwargs: Any,
 ) -> None:
@@ -126,7 +127,7 @@ def asgi_thread_task(
     headers: Optional[Dict[str, Any]],
     seed: Optional[int],
     results: TestResultSet,
-    stateful: Optional[str],
+    stateful: Optional[Stateful],
     stateful_recursion_limit: int,
     kwargs: Any,
 ) -> None:
@@ -148,7 +149,7 @@ def asgi_thread_task(
 
 
 def stop_worker(thread_id: int) -> None:
-    """Raise an error in a thread so it is possible to asynchronously stop thread execution."""
+    """Raise an error in a thread, so it is possible to asynchronously stop thread execution."""
     ctypes.pythonapi.PyThreadState_SetAsyncExc(ctypes.c_long(thread_id), ctypes.py_object(SystemExit))
 
 
@@ -177,7 +178,7 @@ class ThreadPoolRunner(BaseRunner):
             while not is_finished:
                 # Sleep is needed for performance reasons
                 # each call to `is_alive` of an alive worker waits for a lock
-                # iterations without waiting are too frequent and a lot of time will be spent on waiting for this locks
+                # iterations without waiting are too frequent, and a lot of time will be spent on waiting for this locks
                 time.sleep(0.001)
                 is_finished = all(not worker.is_alive() for worker in workers)
                 while not events_queue.empty():
