@@ -9,6 +9,7 @@ import requests
 
 from ...exceptions import get_response_type_error, get_schema_validation_error, get_status_code_error
 from ...utils import GenericResponse, are_content_types_equal, parse_content_type
+from .schemas import BaseOpenAPISchema
 
 if TYPE_CHECKING:
     from ...models import Case
@@ -39,14 +40,14 @@ def _expand_responses(responses: Dict[Union[str, int], Any]) -> Generator[int, N
 
 
 def content_type_conformance(response: GenericResponse, case: "Case") -> Optional[bool]:
-    from .schemas import BaseOpenAPISchema
-
     if not isinstance(case.endpoint.schema, BaseOpenAPISchema):
         raise TypeError("This check can be used only with Open API schemas")
     content_types = case.endpoint.schema.get_content_types(case.endpoint, response)
     if not content_types:
         return None
-    content_type = response.headers["Content-Type"]
+    content_type = response.headers.get("Content-Type")
+    if not content_type:
+        return None
     for option in content_types:
         if are_content_types_equal(option, content_type):
             return None
@@ -61,8 +62,6 @@ def content_type_conformance(response: GenericResponse, case: "Case") -> Optiona
 
 
 def response_schema_conformance(response: GenericResponse, case: "Case") -> None:
-    from .schemas import BaseOpenAPISchema
-
     if not isinstance(case.endpoint.schema, BaseOpenAPISchema):
         raise TypeError("This check can be used only with Open API schemas")
     try:
@@ -95,7 +94,7 @@ def response_schema_conformance(response: GenericResponse, case: "Case") -> None
             jsonschema.validate(data, schema, cls=jsonschema.Draft4Validator, resolver=resolver)
     except jsonschema.ValidationError as exc:
         exc_class = get_schema_validation_error(exc)
-        raise exc_class(f"The received response does not conform to the defined schema!\n\nDetails: \n\n{exc}")
+        raise exc_class(f"The received response does not conform to the defined schema!\n\nDetails: \n\n{exc}") from exc
     return None  # explicitly return None for mypy
 
 
@@ -103,7 +102,7 @@ def response_schema_conformance(response: GenericResponse, case: "Case") -> None
 def in_scopes(resolver: jsonschema.RefResolver, scopes: List[str]) -> Generator[None, None, None]:
     """Push all available scopes into the resolver.
 
-    There could be an additional scope change during schema resolving in `get_response_schema`, so in total there
+    There could be an additional scope change during a schema resolving in `get_response_schema`, so in total there
     could be a stack of two scopes maximum. This context manager handles both cases (1 or 2 scope changes) in the same
     way.
     """
