@@ -7,11 +7,11 @@ from typing import Any, Dict, List, NoReturn, Optional, Sequence, Tuple
 
 import attr
 
-from ..._hypothesis import LOCATION_TO_CONTAINER
 from ...models import Case, Endpoint
 from ...stateful import ParsedData, StatefulTest
 from ...utils import NOT_SET, GenericResponse
 from . import expressions
+from .constants import LOCATION_TO_CONTAINER
 
 
 @attr.s(slots=True)  # pragma: no mutate
@@ -86,7 +86,7 @@ class Link(StatefulTest):
             for location, container_name in LOCATION_TO_CONTAINER.items():
                 variant = _templates[location]
                 # There could be no schema defined for e.g. `query`, then the container in the `Endpoint` instance
-                # is `None`. The resulting
+                # is `None`.
                 if variant is not None:
                     variants[container_name].append(variant)
 
@@ -102,20 +102,7 @@ class Link(StatefulTest):
             make_variants(item, templates)
             add_variants(templates)
         components = self._convert_to_schema(variants)
-        return self.endpoint.__class__(
-            path=self.endpoint.path,
-            method=self.endpoint.method,
-            definition=self.endpoint.definition,
-            schema=self.endpoint.schema,
-            app=self.endpoint.app,
-            base_url=self.endpoint.base_url,
-            path_parameters=components["path_parameters"],
-            query=components["query"],
-            headers=components["headers"],
-            cookies=components["cookies"],
-            body=components["body"],
-            form_data=self.endpoint.form_data,
-        )
+        return self.endpoint.clone(**components)
 
     def _get_container_by_parameter_name(
         self, full_name: str, templates: Dict[str, Optional[Dict[str, Any]]]
