@@ -6,16 +6,16 @@ from urllib.parse import urlsplit
 
 import jsonschema
 from hypothesis.strategies import SearchStrategy
-from requests.structures import CaseInsensitiveDict
 
 from ...exceptions import InvalidSchema
-from ...hooks import HookContext
+from ...hooks import HookContext, HookDispatcher
 from ...models import Case, Endpoint, EndpointDefinition, empty_object
 from ...schemas import BaseSchema
-from ...stateful import StatefulTest
+from ...stateful import Feedback, Stateful, StatefulTest
 from ...types import FormData
 from ...utils import GenericResponse
 from . import links, serialization
+from ._hypothesis import get_case_strategy
 from .converter import to_json_schema_recursive
 from .examples import get_strategies_from_examples
 from .filters import should_skip_by_operation_id, should_skip_by_tag, should_skip_endpoint, should_skip_method
@@ -35,9 +35,9 @@ class BaseOpenAPISchema(BaseSchema):
         raise NotImplementedError
 
     def get_stateful_tests(
-        self, response: GenericResponse, endpoint: Endpoint, stateful: Optional[str]
+        self, response: GenericResponse, endpoint: Endpoint, stateful: Optional[Stateful]
     ) -> Sequence[StatefulTest]:
-        if stateful == "links":
+        if stateful == Stateful.links:
             return links.get_links(response, endpoint, field=self.links_field)
         return []
 
@@ -45,14 +45,6 @@ class BaseOpenAPISchema(BaseSchema):
         info = self.raw_schema["info"]
         return f"{self.__class__.__name__} for {info['title']} ({info['version']})"
 
-    @property
-    def endpoints(self) -> Dict[str, CaseInsensitiveDict]:
-        if not hasattr(self, "_endpoints"):
-            # pylint: disable=attribute-defined-outside-init
-            endpoints = self.get_all_endpoints()
-            self._endpoints = endpoints_to_dict(endpoints)
-        return self._endpoints
-
     def get_all_endpoints(self) -> Generator[Endpoint, None, None]:
         try:
             paths = self.raw_schema["paths"]  # pylint: disable=unsubscriptable-object
@@ -79,8 +71,8 @@ class BaseOpenAPISchema(BaseSchema):
                     # It could be used for response validation
                     raw_definition = EndpointDefinition(raw_methods[method], resolved_definition, scope)
                     yield self.make_endpoint(path, method, parameters, resolved_definition, raw_definition)
-        except (KeyError, AttributeError, jsonschema.exceptions.RefResolutionError):
-            raise InvalidSchema("Schema parsing failed. Please check your schema.")
+        except (KeyError, AttributeError, jsonschema.exceptions.RefResolutionError) as exc:
+            raise InvalidSchema("Schema parsing failed. Please check your schema.") from exc
 
     def _resolve_methods(self, methods: Dict[str, Any]) -> Tuple[str, Dict[str, Any]]:
         # We need to know a proper scope in what methods are.
@@ -98,10 +90,15 @@ class BaseOpenAPISchema(BaseSchema):
         resolved_definition: Dict[str, Any],
         raw_definition: EndpointDefinition,
     ) -> Endpoint:
-        """Create JSON schemas for query, body, etc from Swagger parameters definitions."""
+        """Create JSON schemas for the query, body, etc from Swagger parameters definitions."""
         base_url = self.get_base_url()
         endpoint = Endpoint(
-            path=path, method=method.upper(), definition=raw_definition, base_url=base_url, app=self.app, schema=self,
+            path=path,
+            method=method.upper(),
+            definition=raw_definition,
+            base_url=base_url,
+            app=self.app,
+            schema=self,
         )
         for parameter in parameters:
             self.process_parameter(endpoint, parameter)
@@ -129,7 +126,7 @@ class BaseOpenAPISchema(BaseSchema):
         raise NotImplementedError
 
     def get_strategies_from_examples(self, endpoint: Endpoint) -> List[SearchStrategy[Case]]:
-        """Get examples from endpoint."""
+        """Get examples from the endpoint."""
         raise NotImplementedError
 
     def get_response_schema(self, definition: Dict[str, Any], scope: str) -> Tuple[List[str], Optional[Dict[str, Any]]]:
@@ -172,6 +169,20 @@ class BaseOpenAPISchema(BaseSchema):
         raw_definition = EndpointDefinition(data, resolved_definition, scope)
         return self.make_endpoint(path, method, parameters, resolved_definition, raw_definition)
 
+    def get_case_strategy(
+        self, endpoint: Endpoint, hooks: Optional[HookDispatcher] = None, feedback: Optional[Feedback] = None
+    ) -> SearchStrategy:
+        return get_case_strategy(endpoint, hooks, feedback)
+
+    def get_hypothesis_conversion(self, endpoint: Endpoint, location: str) -> Optional[Callable]:
+        definitions = [item for item in endpoint.definition.resolved.get("parameters", []) if item["in"] == location]
+        if definitions:
+            return self._get_hypothesis_conversion(definitions)
+        return None
+
+    def _get_hypothesis_conversion(self, definitions: List[Dict[str, Any]]) -> Optional[Callable]:
+        raise NotImplementedError
+
 
 class SwaggerV20(BaseOpenAPISchema):
     nullable_name = "x-nullable"
@@ -193,7 +204,7 @@ class SwaggerV20(BaseOpenAPISchema):
         return self.raw_schema.get("basePath", "/")
 
     def get_strategies_from_examples(self, endpoint: Endpoint) -> List[SearchStrategy[Case]]:
-        """Get examples from endpoint."""
+        """Get examples from the endpoint."""
         return get_strategies_from_examples(endpoint, self.examples_field)
 
     def process_by_type(self, endpoint: Endpoint, parameter: Dict[str, Any]) -> None:
@@ -264,7 +275,7 @@ class SwaggerV20(BaseOpenAPISchema):
             return produces
         return self.raw_schema.get("produces", [])
 
-    def get_hypothesis_conversion(self, definitions: List[Dict[str, Any]]) -> Optional[Callable]:
+    def _get_hypothesis_conversion(self, definitions: List[Dict[str, Any]]) -> Optional[Callable]:
         return serialization.serialize_swagger2_parameters(definitions)
 
     def prepare_multipart(
@@ -330,7 +341,7 @@ class OpenApi30(SwaggerV20):  # pylint: disable=too-many-ancestors
         resolved_definition: Dict[str, Any],
         raw_definition: EndpointDefinition,
     ) -> Endpoint:
-        """Create JSON schemas for query, body, etc from Swagger parameters definitions."""
+        """Create JSON schemas for the query, body, etc from Swagger parameters definitions."""
         endpoint = super().make_endpoint(path, method, parameters, resolved_definition, raw_definition)
         if "requestBody" in resolved_definition:
             self.process_body(endpoint, resolved_definition["requestBody"])
@@ -389,15 +400,15 @@ class OpenApi30(SwaggerV20):  # pylint: disable=too-many-ancestors
         return scopes, None
 
     def get_strategies_from_examples(self, endpoint: Endpoint) -> List[SearchStrategy[Case]]:
-        """Get examples from endpoint."""
+        """Get examples from the endpoint."""
         return get_strategies_from_examples(endpoint, self.examples_field)
 
     def get_content_types(self, endpoint: Endpoint, response: GenericResponse) -> List[str]:
         try:
             responses = endpoint.definition.raw["responses"]
-        except KeyError:
+        except KeyError as exc:
             # Possible to get if `validate_schema=False` is passed during schema creation
-            raise InvalidSchema("Schema parsing failed. Please check your schema.")
+            raise InvalidSchema("Schema parsing failed. Please check your schema.") from exc
         status_code = str(response.status_code)
         if status_code in responses:
             definitions = responses[status_code]
@@ -407,7 +418,7 @@ class OpenApi30(SwaggerV20):  # pylint: disable=too-many-ancestors
             return []
         return list(definitions.get("content", {}).keys())
 
-    def get_hypothesis_conversion(self, definitions: List[Dict[str, Any]]) -> Optional[Callable]:
+    def _get_hypothesis_conversion(self, definitions: List[Dict[str, Any]]) -> Optional[Callable]:
         return serialization.serialize_openapi3_parameters(definitions)
 
     def get_request_payload_content_types(self, endpoint: Endpoint) -> List[str]:
@@ -454,16 +465,8 @@ def get_common_parameters(methods: Dict[str, Any]) -> List[Dict[str, Any]]:
     return []
 
 
-def endpoints_to_dict(endpoints: Generator[Endpoint, None, None]) -> Dict[str, CaseInsensitiveDict]:
-    output: Dict[str, CaseInsensitiveDict] = {}
-    for endpoint in endpoints:
-        output.setdefault(endpoint.path, CaseInsensitiveDict())
-        output[endpoint.path][endpoint.method] = endpoint
-    return output
-
-
 def get_schema_from_parameter(data: Dict[str, Any]) -> Dict[str, Any]:
-    # In Open API 3.0 there could be "schema" or "content" field. They are mutually exclusive
+    # In Open API 3.0 there could be "schema" or "content" field. They are mutually exclusive.
     if "schema" in data:
         return data["schema"]
     options = iter(data["content"].values())
